==> lockdown_protocol_extra_bot-0.0.1-py3-none-any.whl: lockdown_protocol_extra_bot/gen_challenges.py <==
# coding: utf-8

from ksupk import save_json


def get_challenges() -> dict:
    """
    describe - описание чэлленджа, которое будет показываться игроку. Вместо {rnd_player} будет подставляться цвет игрока.
    weight - вес шанса выбора этого чэлленджа
    apper_chance - шанс появления в списке чэлленджей (в процентах)
    """
    # "": {"describe": "", "weight": 0, "apper_chance": 100},
    d = {
        "0.0": {"describe": "Ничего не надо делать дополнительного. Чэлленджей нет. Кайфуй и играй как обычно. ", "weight": 25, "apper_chance": 50},
        "0.1": {"describe": "Ничего не надо делать дополнительного. Чэлленджей нет. Кайфуй и играй как обычно. ", "weight": 25, "apper_chance": 25},
        "0":   {"describe": "Ничего не надо делать дополнительного. Чэлленджей нет. Кайфуй и играй как обычно. ", "weight": 40, "apper_chance": 100},
        "1": {"describe": "Ты Жёлтый ман. Любой ценой ликвидируйте игрока {rnd_player}. ", "weight": 50, "apper_chance": 50},
        "2": {"describe": "Вы диссидент. Выполняйте роль диссидент теперь. ", "weight": 5, "apper_chance": 25},
        "3": {"describe": "Не используйте вообще второй слот. У вас только одна рука. ", "weight": 2, "apper_chance": 100},
        "4": {"describe": "Играйте без звука (или снимите наушники). ", "weight": 2, "apper_chance": 100},
        "5": {"describe": "Играйте без микрофона, запрещено что-либо говорить голосом. ", "weight": 5, "apper_chance": 100},
        "6": {"describe": "Говорить в микрофон только слова, начинающиеся на гласную. ", "weight": 3, "apper_chance": 85},
        "7": {"describe": "Говорить в микрофон только слова, начинающиеся на согласную. ", "weight": 3, "apper_chance": 85},
        "8": {"describe": "Нельзя говорить, можно только петь. ", "weight": 7, "apper_chance": 100},
        "9": {"describe": "Нельзя говорить, можно только читать рэп. ", "weight": 7, "apper_chance": 100},
        "10": {"describe": "Нельзя выполнять задания собственноручно, можно только наблюдать или коммандовать", "weight": 3, "apper_chance": 100},
        "11": {"describe": "Спрячь втайне от всех любой предмет, нужный для выполнения задания. И не трогай его. ", "weight": 5, "apper_chance": 100},
        "12": {"describe": "Любой ценой открой чемодан с оружием. ", "weight": 5, "apper_chance": 100},
        "13": {"describe": "Ты пацифист. Никого ни прикаких условиях нельзя ранить. ", "weight": 20, "apper_chance": 100},
        "14": {"describe": "Говорить только на любом иностранном языке (например, английском). ", "weight": 7, "apper_chance": 100},
        "15": {"describe": "Заставить любой ценой любого игрока прекратить выполнять его текущее задание и обязательно выполни это задание сам. ", "weight": 7, "apper_chance": 100},
        "16": {"describe": "Призрак: стараться любой ценой, как можно меньше времени проводить в поле зрения любого игрока. Спрячься! ", "weight": 1, "apper_chance": 70},
        "17": {"describe": "Псина-призрак: стараться любой ценой, как можно меньше времени проводить в поле зрения любого игрока. Спрячься! Если тебя нашёл игрок через 60 сек после начала матча, то ликвидируй его. ", "weight": 1, "apper_chance": 50},
        "18": {"describe": "Всегда врать. ", "weight": 5, "apper_chance": 100},
        "19": {"describe": "Вооружись! Найди срочно хотя бы одно из этих оружий: любой огнестрел или нож. Морепродукты -- это не оружие! ", "weight": 10, "apper_chance": 100},
        "20": {"describe": "Детектив: раскрой любого диссидента и ликвидируй его любой ценой. ", "weight": 10, "apper_chance": 100},
        "21": {"describe": "Всегда говори вместо любых слов: \"I use Arch BTW!\". ", "weight": 1, "apper_chance": 100},
        "22": {"describe": "Всегда напоминай всем, что ты любишь играть в танки (даже если это не так). ", "weight": 2, "apper_chance": 100},
        "23": {"describe": "В соло! Выполни в соло одно из этих заданий: приготовить всю еду соло, разнести все посылки соло, выполнить все таски по компьютерам соло, всё исследовать соло, сканнер соло. Выполни это **соло** любой ценой. ", "weight": 4, "apper_chance": 100},
        "24": {"describe": "Завали публично (типа нечаянно) одно задание специально один раз. ", "weight": 8, "apper_chance": 100},
        "25": {"describe": "Дальтоунизм. Называй всех игроков не их цветами. ", "weight": 10, "apper_chance": 100},
        "26": {"describe": "Перескажи любому игроку кратко сюжет любой книги, которую он до этого не знал. Если не можешь с книгой, тогда пусть это будет фильм. ", "weight": 3, "apper_chance": 100},
        "27": {"describe": "Публично при хотя бы двух игроках (чтобы они видели) выкинь на пол 5 единиц морепродуктов. ", "weight": 5, "apper_chance": 100},
        "28": {"describe": "Заставь рассмеяться одного из игроков. ", "weight": 3, "apper_chance": 100},
        "29": {"describe": "Заставь игрока {rnd_player} зайти в камеру сканирования (в мед. отсеке), так чтобы вы оказались там вдвоём, хотя бы на 5 сек. ", "weight": 10, "apper_chance": 75},
        "30": {"describe": "Заставь игрока {rnd_player} зайти в оружейную (напротив комнаты с камерами), так чтобы вы оказались там вдвоём, хотя бы на 5 сек. ", "weight": 10, "apper_chance": 75},
        "31": {"describe": "Заставь игрока {rnd_player} взять отвёртку, ударить ей тебя, и отдать отвётку тебе. После этого 2 раза ударь его этой же отвёрткой. ", "weight": 10, "apper_chance": 75},
        "32": {"describe": "Подходи к каждому игроку и объясняй как делать задание (даже если он знает как). ", "weight": 10, "apper_chance": 100},
        "33": {"describe": "Ходи всё время с игроком {rnd_player}. ", "weight": 10, "apper_chance": 75},
        "34": {"describe": "Ходи всё время за игроком {rnd_player} и комментируй все его действия вслух в микрофон. ", "weight": 10, "apper_chance": 75},
        "35": {"describe": "Ходи всё время за игроком {rnd_player} и рассказывай, как нужно играть и делать задания. Если он не делает задания, то заставь его делать. ", "weight": 10, "apper_chance": 75},
        "36": {"describe": "Любой ценой найди и включай кассету на полную громкость в одном любом помещении, пока там работают игроки. ", "weight": 5, "apper_chance": 100},
        "37": {"describe": "Всё время обвиняй в диссидентве игрока {rnd_player}. ", "weight": 10, "apper_chance": 75},
        "38": {"describe": "При любом случае публично говори, что именно ты диссидент. ", "weight": 5, "apper_chance": 100},
        "39": {"describe": "Играй аккумулятором в пинг-понг об стену в течении 30 секунд публично. ", "weight": 5, "apper_chance": 100},
        "40": {"describe": "Найди C4 и спрашивай громко у всех: \"Где детонатор?!\". Если детонатор найден, то спрячь его втайне от всех, и спрашивай опять. ", "weight": 5, "apper_chance": 100},
        "41": {"describe": "Делай вид, что ты разговаривашь по телефону с кем-то прямо в микрофон. ", "weight": 5, "apper_chance": 100},
        "42": {"describe": "Нельзя говорить, можно только петь или читать рэп. Это делать нужно только с рифмой. ", "weight": 3, "apper_chance": 100},
        "43": {"describe": "Заставь игрока {rnd_player} поверить, что именно ты диссидент. ", "weight": 5, "apper_chance": 75},
        "44": {"describe": "Заставь любого игрока поверить, что именно ты диссидент. ", "weight": 3, "apper_chance": 90},
        "45": {"describe": "Делай вид, что ты всё время очень торопишься. Недоумевай почему остальные делают всё так медленно. ", "weight": 5, "apper_chance": 100},
        "46": {"describe": "Всё время ной и ори: \"Ну почему тут нету помощи?!\" ", "weight": 5, "apper_chance": 100},
        "47": {"describe": "Каждый раз при выполнении задания, собирай игроков (хотя бы двоих, не считая тебя) в любой комнате, если это возможно, и говори напутственную речь, о том, как вы хорошо все справляетесь. ", "weight": 5, "apper_chance": 100},
        "48": {"describe": "Клиптоман: Находи все отвёртки и прячь их любой ценой. ", "weight": 5, "apper_chance": 100},
        "49": {"describe": "Пытайся заставить игрока {rnd_player} спрятать нужную для задания вещь. ", "weight": 5, "apper_chance": 75},
        "50": {"describe": "Если ты встретишь любого игрока спустя 60 сек после начала игры, то спрашивай у него каждый раз, где здесь находится столовая. ", "weight": 5, "apper_chance": 100},
        "51": {"describe": "Стой на спавне первые 30 сек. ", "weight": 5, "apper_chance": 100},
        "52": {"describe": "Каждый раз, когда на таймере секунды выстроились в \"00\" громко перди в микрофон. ", "weight": 5, "apper_chance": 100},
        "53": {"describe": "Используй для общения только 5 любых слов. ", "weight": 5, "apper_chance": 100},
        "54": {"describe": "Делай вид, будто игрока {rnd_player} вообще нет в игре. ", "weight": 10, "apper_chance": 75},
        "55": {"describe": "Спустя 30 секунд после начала игры запрещено иметь максимального хп больше 50. ", "weight": 5, "apper_chance": 100},
        "56": {"describe": "Спустя 60 секунд после начала игры ударяй каждого встречного чем-нибудь. ", "weight": 1, "apper_chance": 100},
        "57": {"describe": "Всё время настаивай на том, что тебя тут вообще не должно быть. ", "weight": 5, "apper_chance": 100},
        "58": {"describe": "Всё время настаивай на том, что игрок {rnd_player} всё делает неправильно. ", "weight": 5, "apper_chance": 75},
        "59": {"describe": "Если есть задание на доставку, то отнеси коробку не туда любой ценой один раз. ", "weight": 2, "apper_chance": 100},
        "60": {"describe": "Выстреливай в воздух из всего огнестрела, которое найдёшь, чтобы разорущить оружие. ", "weight": 5, "apper_chance": 100},
        "61": {"describe": "Ударь игрока {rnd_player} морепродуктами один раз. ", "weight": 5, "apper_chance": 75},
        "62": {"describe": "Добеги, как можно скорее, от pressure room (где взрывать баллоны) до лаборатории (где травы сканировать) 2 раза. ", "weight": 5, "apper_chance": 100},
        "63": {"describe": "Если есть задание на готовку, то приготовь не то один раз любой ценой. ", "weight": 5, "apper_chance": 100},
        "64": {"describe": "Когда говоришь в микровон, то всё время переключай его (на \"t\" или колёсиком мыши по умолчанию). ", "weight": 5, "apper_chance": 100},
    }

    return d


if __name__ == "__main__":
    chlngs = get_challenges()
    save_json("./assets/challenges.json", chlngs)

==> lockdown_protocol_extra_bot-0.0.4-py3-none-any.whl: lockdown_protocol_extra_bot/gen_challenges.py <==
# coding: utf-8

from ksupk import save_json


def get_challenges() -> dict:
    """
    describe - description of the challenge that will be shown to the player. The player's color will be substituted for {rnd_player}.
    weight - weight of the chance of choosing this challenge
    apper_chance - chance of appearing in the list of challenges (in percent)

    describe - описание чэлленджа, которое будет показываться игроку. Вместо {rnd_player} будет подставляться цвет игрока.
    weight - вес шанса выбора этого чэлленджа
    apper_chance - шанс появления в списке чэлленджей (в процентах)
    """
    # "": {"describe": "", "weight": 0, "apper_chance": 100},
    d = {
        "0":   {"describe": "Ничего не надо делать дополнительного. Чэлленджей нет. Кайфуй и играй как обычно. ", "weight": 40, "apper_chance": 100},
        "0.0": {"describe": "Ничего не надо делать дополнительного. Чэлленджей нет. Кайфуй и играй как обычно. ", "weight": 25, "apper_chance": 50},
        "0.1": {"describe": "Ничего не надо делать дополнительного. Чэлленджей нет. Кайфуй и играй как обычно. ", "weight": 25, "apper_chance": 25},
        "0.2": {"describe": "Ничего не надо делать дополнительного. Чэлленджей нет. Кайфуй и играй как обычно. ", "weight": 10, "apper_chance": 10},
        "1": {"describe": "Ты Жёлтый ман. Любой ценой ликвидируйте игрока {rnd_player}. ", "weight": 50, "apper_chance": 50},
        "1.1": {"describe": "Ты Жёлтый ман. Любой ценой ликвидируйте игрока {rnd_player}. ", "weight": 10, "apper_chance": 10},
        "2": {"describe": "Вы диссидент. Выполняйте роль диссидент теперь. ", "weight": 5, "apper_chance": 25},
        "3": {"describe": "Не используйте вообще второй слот. У вас только одна рука и нет карманов. ", "weight": 3, "apper_chance": 100},
        "4": {"describe": "Играйте без звука (или снимите наушники). ", "weight": 2, "apper_chance": 50},
        "5": {"describe": "Играйте без микрофона, запрещено что-либо говорить голосом. ", "weight": 5, "apper_chance": 50},
        "6": {"describe": "Говорить в микрофон только слова, начинающиеся на гласную. ", "weight": 3, "apper_chance": 85},
        "7": {"describe": "Говорить в микрофон только слова, начинающиеся на согласную. ", "weight": 3, "apper_chance": 85},
        "8": {"describe": "Нельзя говорить, можно только петь. ", "weight": 7, "apper_chance": 100},
        "9": {"describe": "Нельзя говорить, можно только читать рэп. ", "weight": 7, "apper_chance": 100},
        "10": {"describe": "Нельзя выполнять задания собственноручно, можно только наблюдать или коммандовать", "weight": 3, "apper_chance": 100},
        "11": {"describe": "Спрячь втайне от всех любой предмет, нужный для выполнения задания. И не трогай его. ", "weight": 5, "apper_chance": 100},
        "12": {"describe": "Любой ценой открой чемодан с оружием. ", "weight": 5, "apper_chance": 100},
        "13": {"describe": "Ты пацифист. Никого ни прикаких условиях нельзя ранить. ", "weight": 20, "apper_chance": 100},
        "14": {"describe": "Говорить только на любом иностранном языке (например, английском). ", "weight": 7, "apper_chance": 100},
        "15": {"describe": "Заставить любой ценой любого игрока прекратить выполнять его текущее задание, а после обязательно выполни это задание сам. ", "weight": 7, "apper_chance": 100},
        "16": {"describe": "Призрак: стараться любой ценой, как можно меньше времени проводить в поле зрения любого игрока. Спрячься! ", "weight": 1, "apper_chance": 70},
        "17": {"describe": "Псина-призрак: стараться любой ценой, как можно меньше времени проводить в поле зрения любого игрока. Спрячься! Если тебя нашёл игрок через 60 сек после начала матча, то ликвидируй его. ", "weight": 1, "apper_chance": 50},
        "18": {"describe": "Всегда врать. ", "weight": 5, "apper_chance": 100},
        "19": {"describe": "Вооружись! Найди срочно хотя бы одно из этих оружий: любой огнестрел или нож. Морепродукты -- это не оружие! ", "weight": 10, "apper_chance": 100},
        "20": {"describe": "Детектив: раскрой любого диссидента и ликвидируй его любой ценой. ", "weight": 10, "apper_chance": 100},
        "21": {"describe": "Всегда говори вместо любых слов: \"I use Arch BTW!\". ", "weight": 1, "apper_chance": 100},
        "22": {"describe": "Всегда напоминай всем, что ты любишь играть в танки (даже если это не так). ", "weight": 2, "apper_chance": 100},
        "23": {"describe": "В соло! Выполни в соло одно из этих заданий: приготовить всю еду соло, разнести все посылки соло, выполнить все таски по компьютерам соло, всё исследовать соло, сканнер соло. Выполни это **соло** любой ценой. ", "weight": 4, "apper_chance": 100},
        "24": {"describe": "Завали публично (типа нечаянно) одно задание специально один раз. ", "weight": 8, "apper_chance": 100},
        "25": {"describe": "Дальтоунизм. Называй всех игроков не их цветами. ", "weight": 10, "apper_chance": 100},
        "26": {"describe": "Перескажи любому игроку кратко сюжет любой книги, которую он до этого не знал. Если не можешь с книгой, тогда пусть это будет фильм. ", "weight": 3, "apper_chance": 100},
        "27": {"describe": "Публично при хотя бы двух игроках (чтобы они видели) выкинь на пол 5 единиц морепродуктов. ", "weight": 5, "apper_chance": 100},
        "28": {"describe": "Заставь рассмеяться одного из игроков. ", "weight": 3, "apper_chance": 100},
        "29": {"describe": "Заставь игрока {rnd_player} зайти в камеру сканирования (в мед. отсеке), так чтобы вы оказались там вдвоём, хотя бы на 5 сек. ", "weight": 10, "apper_chance": 75},
        "30": {"describe": "Заставь игрока {rnd_player} зайти в оружейную (напротив комнаты с камерами), так чтобы вы оказались там вдвоём, хотя бы на 5 сек. ", "weight": 10, "apper_chance": 75},
        "31": {"describe": "Заставь игрока {rnd_player} взять отвёртку, ударить ей тебя, и отдать отвётку тебе. После этого 2 раза ударь его этой же отвёрткой. ", "weight": 10, "apper_chance": 75},
        "32": {"describe": "Подходи к каждому игроку и объясняй как делать задание (даже если он знает как). ", "weight": 10, "apper_chance": 100},
        "33": {"describe": "Ходи всё время с игроком {rnd_player}. ", "weight": 10, "apper_chance": 75},
        "34": {"describe": "Ходи всё время за игроком {rnd_player} и комментируй все его действия вслух в микрофон. ", "weight": 10, "apper_chance": 75},
        "35": {"describe": "Ходи всё время за игроком {rnd_player} и рассказывай, как нужно играть и делать задания. Если он не делает задания, то заставь его делать. ", "weight": 10, "apper_chance": 75},
        "36": {"describe": "Любой ценой найди и включай кассету на полную громкость в одном любом помещении, пока там работают игроки. ", "weight": 5, "apper_chance": 100},
        "37": {"describe": "Всё время обвиняй в диссидентве игрока {rnd_player}. ", "weight": 10, "apper_chance": 75},
        "38": {"describe": "При любом случае публично говори, что именно ты диссидент. ", "weight": 5, "apper_chance": 100},
        "39": {"describe": "Играй аккумулятором в пинг-понг об стену в течении 30 секунд публично. ", "weight": 5, "apper_chance": 100},
        "40": {"describe": "Найди C4 и спрашивай громко у всех: \"Где детонатор?!\". Если детонатор найден, то спрячь его втайне от всех, и спрашивай опять. ", "weight": 5, "apper_chance": 100},
        "41": {"describe": "Делай вид, что ты разговаривашь по телефону с кем-то прямо в микрофон. ", "weight": 5, "apper_chance": 100},
        "42": {"describe": "Нельзя говорить, можно только петь или читать рэп. Это делать нужно только с рифмой. ", "weight": 3, "apper_chance": 100},
        "43": {"describe": "Заставь игрока {rnd_player} поверить, что именно ты диссидент. ", "weight": 5, "apper_chance": 75},
        "44": {"describe": "Заставь любого игрока поверить, что именно ты диссидент. ", "weight": 3, "apper_chance": 90},
        "45": {"describe": "Делай вид, что ты всё время очень торопишься. Недоумевай почему остальные делают всё так медленно. ", "weight": 5, "apper_chance": 100},
        "46": {"describe": "Всё время ной и ори: \"Ну почему тут нету помощи?!\" ", "weight": 5, "apper_chance": 100},
        "47": {"describe": "Каждый раз при выполнении задания, собирай игроков (хотя бы двоих, не считая тебя) в любой комнате, если это возможно, и говори напутственную речь, о том, как вы хорошо все справляетесь. ", "weight": 5, "apper_chance": 100},
        "48": {"describe": "Клиптоман: Находи все отвёртки и прячь их любой ценой. ", "weight": 5, "apper_chance": 100},
        "49": {"describe": "Пытайся заставить игрока {rnd_player} спрятать нужную для задания вещь. ", "weight": 5, "apper_chance": 75},
        "50": {"describe": "Если ты встретишь любого игрока спустя 60 сек после начала игры, то спрашивай у него каждый раз, где здесь находится столовая. ", "weight": 5, "apper_chance": 100},
        "51": {"describe": "Стой на спавне первые 30 сек. ", "weight": 5, "apper_chance": 100},
        "52": {"describe": "Каждый раз, когда на таймере секунды выстроились в \"00\" громко перди в микрофон. ", "weight": 5, "apper_chance": 100},
        "53": {"describe": "Используй для общения только 5 любых слов. ", "weight": 5, "apper_chance": 100},
        "54": {"describe": "Делай вид, будто игрока {rnd_player} вообще нет в игре. ", "weight": 10, "apper_chance": 75},
        "55": {"describe": "Спустя 30 секунд после начала игры запрещено иметь максимального хп больше 50. ", "weight": 5, "apper_chance": 100},
        "56": {"describe": "Спустя 60 секунд после начала игры ударяй каждого встречного чем-нибудь. ", "weight": 1, "apper_chance": 100},
        "57": {"describe": "Всё время настаивай на том, что тебя тут вообще не должно быть. ", "weight": 5, "apper_chance": 100},
        "58": {"describe": "Всё время настаивай на том, что игрок {rnd_player} всё делает неправильно. ", "weight": 5, "apper_chance": 75},
        "59": {"describe": "Если есть задание на доставку, то отнеси коробку не туда любой ценой один раз. ", "weight": 2, "apper_chance": 100},
        "60": {"describe": "Выстреливай в воздух из всего огнестрела, которое найдёшь, чтобы разорущить оружие. ", "weight": 5, "apper_chance": 100},
        "61": {"describe": "Ударь игрока {rnd_player} морепродуктами один раз. ", "weight": 5, "apper_chance": 75},
        "62": {"describe": "Добеги, как можно скорее, от pressure room (где взрывать баллоны) до лаборатории (где травы сканировать) 2 раза. ", "weight": 5, "apper_chance": 100},
        "63": {"describe": "Если есть задание на готовку, то приготовь не то один раз любой ценой. ", "weight": 5, "apper_chance": 100},
        "64": {"describe": "Когда говоришь в микровон, то всё время переключай его (на \"t\" или колёсиком мыши по умолчанию). ", "weight": 5, "apper_chance": 100},
        "65": {"describe": "Играть только левой рукой для правшей, для левшей -- правой. ", "weight": 5, "apper_chance": 100},
        "66": {"describe": "Под конец игры в случае почти точной победы вызвать игрока {rnd_player} (если он ещё в игре, иначе любого другого) на дуэль 1 на 1 при зрителях. ", "weight": 5, "apper_chance": 80},
        "67": {"describe": "Заразный. Держись как можно дальше от любого игрока любыми способами. ", "weight": 5, "apper_chance": 100},
        "68": {"describe": "Beholder. Найди диссидента по камерам. Если ты диссидент, то ты сам себя нашёл уже. ", "weight": 5, "apper_chance": 100},
        "69": {"describe": "Если ты видишь, что кто-то открывает ящик, любыми способами помещай ему это сделать (ввести неверный пин самое простой способ). ", "weight": 5, "apper_chance": 100},
        "70": {"describe": "Демотивируй всегда и всех, рядом находящихся игроков. ", "weight": 5, "apper_chance": 100},
        "71": {"describe": "Нельзя говорить слова, в которых есть буква \"о\". ", "weight": 5, "apper_chance": 100},
        "72": {"describe": "Beholder. Твоя задача всегда держать игрока {rnd_player} в зоне видимости. Прячься и подглядывай, если придётся. ", "weight": 5, "apper_chance": 90},
        "73": {"describe": "Рассказывай всем, чтобы доктор Казейнберг сделал бы на вашем месте. ", "weight": 5, "apper_chance": 100},
        "74": {"describe": "Расскажи хотя бы при одном зрителе любую басню Крылова. ", "weight": 3, "apper_chance": 30},
        "75": {"describe": "Найди соединитель с двух сторон одиннакового цвета. ", "weight": 5, "apper_chance": 100},
        "76": {"describe": "Говори, как пирррррат. Арррр! ", "weight": 5, "apper_chance": 100},
        "77": {"describe": "Приготовь любую еду, если есть такое задание, и отнеси её игроку {rnd_player} (если игрок выбыл, то любому другому) под видом доставщика еды. ", "weight": 5, "apper_chance": 30},
        "78": {"describe": "Будь очень грубым с другими игроками. ", "weight": 5, "apper_chance": 30},
        "79": {"describe": "Работай с игроком {rnd_player} и всё время неправильно ему помогай. ", "weight": 5, "apper_chance": 80},
        "80": {"describe": "Извиняйся каждый раз, когда кого-то ранишь. ", "weight": 5, "apper_chance": 100},
        "81": {"describe": "У тебя за всю игру есть только 15 слов, чтобы сказать. Больше нельзя. Предлоги, союзы, частиты, междометия и т.д. -- это слова. ", "weight": 5, "apper_chance": 100},
    }

    return d


if __name__ == "__main__":
    chlngs = get_challenges()
    save_json("./assets/challenges.json", chlngs)
